# sint

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Developer Guide

### Setup

``` sh
# create conda environment
$ mamba env create -f env.yml

# update conda environment
$ mamba env update -n sint --file env.yml
# $ mamba env update -n sint --file env.mac.yml
```

### Install

``` sh
pip install -e .

# install from pypi
pip install sint
```

### nbdev

``` sh
# activate conda environment
$ conda activate sint

# make sure the sint package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to the sint package
$ nbdev_prepare
```

Note: it might be useful to use the following snippet to enable hot
reloading:

``` python
%load_ext autoreload
%autoreload 2
```

### Publishing

``` sh
# publish to pypi
$ nbdev_pypi

# publish to conda
$ nbdev_conda --build_args '-c conda-forge'
```

# Usage

## Installation

Install latest from the GitHub
[repository](https://github.com/dsm-72/sint):

``` sh
$ pip install git+https://github.com/dsm-72/sint.git
```

or from [conda](https://anaconda.org/dsm-72/sint)

``` sh
$ conda install -c dsm-72 sint
```

or from [pypi](https://pypi.org/project/sint/)

``` sh
$ pip install sint
```

## Examples

``` python
sign.P, sign.Z, sign.N
```

    (sign(int=1, chr='P', sym='+', syn={'positive', '+', 'pos'}),
     sign(int=0, chr='', sym='', syn=set()),
     sign(int=-1, chr='N', sym='-', syn={'negative', 'neg', '-'}))

``` python
sint(2), sint(0), sint(-2), sint('2'), sint('0'), sint('-2'), sint('+'), sint('0'), sint('-')
```

    (1, 0, -1, 1, 0, -1, 1, 0, -1)

``` python
sint(2).chr, sint(2).sym, sint(0).chr, sint(0).sym, sint.tochr(2)
```

    ('P', '+', '', '', 'P')
